@@ -9,11 +9,11 @@ Test::WWW::Mechanize - Testing-specific WWW::Mechanize subclass
 
 =head1 VERSION
 
-Version 1.40
+Version 1.42
 
 =cut
 
-our $VERSION = '1.40';
+our $VERSION = '1.42';
 
 =head1 SYNOPSIS
 
@@ -460,11 +460,19 @@ sub _lint_content_ok {
 
     local $Test::Builder::Level = $Test::Builder::Level + 1;
 
-    if ( not ( eval 'require HTML::Lint' ) ) {
-        die "Test::WWW::Mechanize can't do linting without HTML::Lint: $@";
+    my $module = "HTML::Lint 2.20";
+    if ( not ( eval "use $module; 1;" ) ) {
+        die "Test::WWW::Mechanize can't do linting without $module: $@";
     }
 
-    my $lint = (ref $self->{autolint} && $self->{autolint}->isa('HTML::Lint')) ? $self->{autolint} : HTML::Lint->new();
+    my $lint = $self->{autolint};
+    if ( ref $lint && $lint->isa('HTML::Lint') ) {
+        $lint->newfile;
+        $lint->clear_errors;
+    }
+    else {
+        $lint = HTML::Lint->new();
+    }
 
     $lint->parse( $self->content );
 
@@ -1391,7 +1399,7 @@ autolint status:
 
     my $old_status = $mech->autolint( 0 );
     ... operations that should not be linted ...
-    $mech->autolint->( $old_status );
+    $mech->autolint( $old_status );
 
 =cut
 
@@ -1494,7 +1502,7 @@ sub _grep_hashes {
 }
 
 
-=head2 $mech->scrape_text_by_attr( $attr, $attr [, $html ] )
+=head2 $mech->scrape_text_by_attr( $attr, $attr_value [, $html ] )
 
 =head2 $mech->scrape_text_by_attr( $attr, $attr_regex [, $html ] )
 
@@ -1695,7 +1703,7 @@ and Pete Krawczyk for patches.
 
 Copyright 2004-2012 Andy Lester.
 
-This program is free software; you can redistribute it and/or modify it
+This library is free software; you can redistribute it and/or modify it
 under the terms of the Artistic License version 2.0.
 
 =cut
